#ifndef ASPEQTSETTINGS_H
#define ASPEQTSETTINGS_H

#include <QSettings>

class AspeqtSettings
{
public:
    class ImageSettings {
    public:
        QString fileName;
        bool isWriteProtected;
    };

    AspeqtSettings();
    ~AspeqtSettings();

    void saveSessionToFile(const QString &fileName);
    void loadSessionFromFile(const QString &fileName);

    bool isFirstTime();

    QString serialPortName();
    void setSerialPortName(const QString &name);

    QString atariSioDriverName();
    void setAtariSioDriverName(const QString &name);

    int maximumSerialPortSpeed();
    void setMaximumSerialPortSpeed(int speed);

    int handshakingMethod();
    void setHandshakingMethod(int method);

    int backend();
    void setBackend(int backend);

    ImageSettings getImageSettingsFromName(const QString &fileName);

    ImageSettings mountedImageSetting(int no);
    void setMountedImageSetting(int no, const QString &fileName, bool prot);
    ImageSettings recentImageSetting(int no);

    void mountImage(int no, const QString &fileName, bool prot);
    void unmountImage(int no);
    void swapImages(int no1, int no2);

    QString lastDiskImageDir();
    void setLastDiskImageDir(const QString &dir);

    QString lastFolderImageDir();
    void setLastFolderImageDir(const QString &dir);

    QString lastSessionDir();
    void setLastSessionDir(const QString &dir);

    QString lastExeDir();
    void setLastExeDir(const QString &dir);

    QString lastExtractDir();
    void setLastExtractDir(const QString &dir);
private:
    QSettings *mSettings;

    void writeRecentImageSettings();

    bool mIsFirstTime;
    QString mSerialPortName;
    QString mAtariSioDriverName;
    int mMaximumSerialPortSpeed;
    int mHandshakingMethod;
    int mBackend;
    ImageSettings mMountedImageSettings[8];
    ImageSettings mRecentImageSettings[10];
    QString mLastDiskImageDir;
    QString mLastFolderImageDir;
    QString mLastSessionDir;
    QString mLastExeDir;
    QString mLastExtractDir;
};

extern AspeqtSettings *aspeqtSettings;

#endif // ASPEQTSETTINGS_H
