#include "optionsdialog.h"
#include "ui_optionsdialog.h"

#include "aspeqtsettings.h"

OptionsDialog::OptionsDialog(QWidget *parent) :
    QDialog(parent),
    m_ui(new Ui::OptionsDialog)
{
    Qt::WindowFlags flags = windowFlags();
    flags = flags & (~Qt::WindowContextHelpButtonHint);
    setWindowFlags(flags);

    m_ui->setupUi(this);

    connect(this, SIGNAL(accepted()), this, SLOT(OptionsDialog_accepted()));

    /* Retrieve application settings */
    m_ui->handshakeMethodCombo->setCurrentIndex(aspeqtSettings->handshakingMethod());
    m_ui->maximumSpeedCombo->setCurrentIndex(aspeqtSettings->maximumSerialPortSpeed());
    m_ui->serialPortNameEdit->setText(aspeqtSettings->serialPortName());
    m_ui->sioDriverNameEdit->setText(aspeqtSettings->atariSioDriverName());
#ifdef Q_OS_LINUX
    m_ui->backendCombo->setCurrentIndex(aspeqtSettings->backend());
#else
    m_ui->backendCombo->setCurrentIndex(0);
    m_ui->backendWidget->setVisible(false);
#endif
    on_backendCombo_currentIndexChanged(m_ui->backendCombo->currentIndex());
}

OptionsDialog::~OptionsDialog()
{
    delete m_ui;
}

void OptionsDialog::changeEvent(QEvent *e)
{
    QDialog::changeEvent(e);
    switch (e->type()) {
    case QEvent::LanguageChange:
        m_ui->retranslateUi(this);
        break;
    default:
        break;
    }
}

void OptionsDialog::OptionsDialog_accepted()
{
    QSettings settings;
    aspeqtSettings->setSerialPortName(m_ui->serialPortNameEdit->text());
    aspeqtSettings->setAtariSioDriverName(m_ui->sioDriverNameEdit->text());
    aspeqtSettings->setHandshakingMethod(m_ui->handshakeMethodCombo->currentIndex());
    aspeqtSettings->setMaximumSerialPortSpeed(m_ui->maximumSpeedCombo->currentIndex());
#ifdef Q_OS_LINUX
    aspeqtSettings->setBackend(m_ui->backendCombo->currentIndex());
#endif
}

void OptionsDialog::on_backendCombo_currentIndexChanged(int index)
{
    if (index == 0) {
        m_ui->speedWidget->setVisible(true);
        m_ui->serialPortNameEdit->setVisible(true);
        m_ui->sioDriverNameEdit->setVisible(false);
        m_ui->portNameLabel->setText(tr("Port name"));
    } else {
        m_ui->speedWidget->setVisible(false);
        m_ui->serialPortNameEdit->setVisible(false);
        m_ui->sioDriverNameEdit->setVisible(true);
        m_ui->portNameLabel->setText(tr("AtariSIO driver name"));
    }
}
