#ifndef SERIALPORTUNIX_H
#define SERIALPORTUNIX_H

#include "serialport.h"

class StandardSerialPortBackend : public AbstractSerialPortBackend
{
    Q_OBJECT

public:
    StandardSerialPortBackend(QObject *parent = 0);
    ~StandardSerialPortBackend();

    static QString defaultPortName();

    bool open(QString name, SerialLine method);
    bool isOpen();
    void close();
    void cancel();
    void setSpeed(uint speed);
    uint speed();
    QByteArray readCommandFrame();
    QByteArray readDataFrame(uint size, bool verbose = true);
    bool writeDataFrame(const QByteArray &data);
    bool writeCommandAck();
    bool writeCommandNak();
    bool writeDataAck();
    bool writeDataNak();
    bool writeComplete();
    bool writeError();

private:
    bool mCanceled;
    int mHandle;
    uint mSpeed;
    SerialLine mMethod;
    quint8 sioChecksum(const QByteArray &data, uint size);
    QByteArray readRawFrame(uint size, bool verbose = true);
    bool writeRawFrame(const QByteArray &data);
    QString lastErrorMessage();
};

class AtariSioBackend : public AbstractSerialPortBackend
{
    Q_OBJECT

public:
    AtariSioBackend(QObject *parent = 0);
    ~AtariSioBackend();

    static QString defaultPortName();

    bool open(QString name, SerialLine method);
    bool isOpen();
    void close();
    void cancel();
    void setSpeed(uint speed);
    uint speed();
    QByteArray readCommandFrame();
    QByteArray readDataFrame(uint size, bool verbose = true);
    bool writeDataFrame(const QByteArray &data);
    bool writeCommandAck();
    bool writeCommandNak();
    bool writeDataAck();
    bool writeDataNak();
    bool writeComplete();
    bool writeError();

private:
private:
    int mHandle, mCancelHandles[2];
    uint mSpeed;
    SerialLine mMethod;
    QString lastErrorMessage();
};

#endif // SERIALPORTUNIX_H
