#ifndef SERIALPORT_H
#define SERIALPORT_H

#include <QObject>
#include <QByteArray>

#include "messagetype.h"

class AbstractSerialPortBackend : public QObject
{
    Q_OBJECT
    Q_ENUMS(MessageType::UiMessageType)
    Q_ENUMS(SerialLine)

public:
    enum SerialLine {Ri, Dsr, Cts};
    AbstractSerialPortBackend(QObject *parent = 0);
    virtual ~AbstractSerialPortBackend();
    virtual bool open(QString name, SerialLine method) = 0;
    virtual bool isOpen() = 0;
    virtual void close() = 0;
    virtual void cancel() = 0;
    virtual void setSpeed(uint speed) = 0;
    virtual uint speed() = 0;
    virtual QByteArray readCommandFrame() = 0;
    virtual QByteArray readDataFrame(uint size, bool verbose = true) = 0;
    virtual bool writeDataFrame(const QByteArray &data) = 0;
    virtual bool writeCommandAck() = 0;
    virtual bool writeCommandNak() = 0;
    virtual bool writeDataAck() = 0;
    virtual bool writeDataNak() = 0;
    virtual bool writeComplete() = 0;
    virtual bool writeError() = 0;
signals:
    void uiMessage(const QString message, MessageType::UiMessageType type);
    void speedChanged(uint newSpeed);
};

#ifdef Q_OS_WIN
#include "serialport-win32.h"
#endif
#ifdef Q_OS_UNIX
#include "serialport-unix.h"
#endif

#endif // SERIALPORT_H
